@@ -21,13 +21,26 @@ msc.biomarkers.write.csv = function(X, fname)
   write.csv(A, file=fname, col.names=NA)
 }
 
-msc.biomarkers.read.csv = function(fname) 
+msc.biomarkers.read.csv = function(fname, mzXML.record=FALSE) 
 {
   X = read.csv(fname, comment.char = "", header=TRUE)  
   SampleName = X[,1]
   X = t(X[,-1])
   X[X==0] = NA
   colnames(X) = as.character(SampleName)
+  if (mzXML.record) { # create mzXML record 
+    sha1  = digest(fname, alg="sha1", file=TRUE)
+    mzXML$parentFile = paste(mzXML$parentFile, 
+      "    <parentFile filename='file:///", fname, 
+      "' fileType='processedData' fileSha1='",sha1,"'/>\n", sep="")
+    for (i in 1:ncol(X)) {
+      scanOrigin = paste("<scanOrigin parentFileID='",sha1,"' num='",i,"'/>", sep="");
+      mzXML$scan[[i]] = list(mass=NULL, peaks=NULL, num=i, parentNum=i, 
+        msLevel=1, header=NULL, maldi=NULL, scanOrigin=scanOrigin,
+        precursorMz=NULL, nameValue=NULL)
+    }
+    attr(X,"mzXML") = mzXML
+  }
   return (X)
 }
 
